@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2005-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2005-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -8,8 +8,10 @@
 
 // app includes
 #include "codeimpthread.h"
+#define DBG_SRC QLatin1String("NativeImportBase")
 #include "debug_utils.h"
 #include "import_utils.h"
+#include "uml.h"  // only needed for log{Warn,Error}
 
 // kde includes
 #include <KLocalizedString>
@@ -19,6 +21,8 @@
 #include <QRegExp>
 #include <QTextStream>
 
+DEBUG_REGISTER(NativeImportBase)
+
 QStringList NativeImportBase::m_parsedFiles;  // static, see nativeimportbase.h
 
 /**
@@ -106,7 +110,7 @@ bool NativeImportBase::skipToClosing(QChar opener)
             closing = QLatin1String(">");
             break;
         default:
-            uError() << "opener='" << opener << "': illegal input character";
+            logError1("NativeImportBase::skipToClosing opener='%1': illegal input character", opener);
             return false;
     }
     const QString opening(opener);
@@ -154,6 +158,7 @@ UMLPackage *NativeImportBase::popScope()
 
 /**
  * Return current scope.
+ * If the scope stack is empty then return nullptr.
  *
  * @return scope
  */
@@ -173,6 +178,18 @@ int NativeImportBase::scopeIndex()
     return m_scope.size() - 1;
 }
 
+/**
+ * Get the current lexeme.
+ * If the end of parse was reached then return an empty string.
+ * @return  the current lexeme
+ */
+QString NativeImportBase::current()
+{
+    if (m_srcIndex < m_source.count() - 1)
+        return m_source[m_srcIndex];
+    return QString();
+}
+
 /**
  * Get the next lexeme without advancing.
  * @return  the next lexeme or an empty string
@@ -421,13 +438,13 @@ bool NativeImportBase::parseFile(const QString& filename)
     if (filename.contains(QLatin1Char('/'))) {
         QString path = filename;
         path.remove(QRegExp(QLatin1String("/[^/]+$")));
-        uDebug() << msgPrefix << "adding path " << path;
+        logDebug2("NativeImportBase::parseFile %1 adding path %2", msgPrefix, path);
         Import_Utils::addIncludePath(path);
     }
     if (!QFile::exists(filename)) {
         QFileInfo fi(filename);
         if (fi.isAbsolute()) {
-            uError() << msgPrefix << "cannot find file";
+            logError1("NativeImportBase::parseFile: cannot find absolute file %1", filename);
             return false;
         }
         bool found = false;
@@ -445,13 +462,13 @@ bool NativeImportBase::parseFile(const QString& filename)
             }
         }
         if (! found) {
-            uError() << msgPrefix << "cannot find file";
+            logError1("NativeImportBase::parseFile: cannot find file %1", filename);
             return false;
         }
     }
     QFile file(fname);
     if (! file.open(QIODevice::ReadOnly)) {
-        uError() << msgPrefix << "cannot open file";
+        logError1("NativeImportBase::parseFile: cannot open file %1", fname);
         return false;
     }
     log(nameWithoutPath, QLatin1String("parsing..."));
@@ -473,13 +490,13 @@ bool NativeImportBase::parseFile(const QString& filename)
     m_klass = 0;
     m_currentAccess = Uml::Visibility::Public;
     m_scope.clear();
-    pushScope(Import_Utils::globalScope()); // index 0 is reserverd for the global scope
+    pushScope(Import_Utils::globalScope()); // index 0 is reserved for the global scope
     const int srcLength = m_source.count();
     for (m_srcIndex = 0; m_srcIndex < srcLength; ++m_srcIndex) {
         const QString& firstToken = m_source[m_srcIndex];
         //uDebug() << '"' << firstToken << '"';
         if (firstToken.startsWith(m_singleLineCommentIntro)) {
-            m_comment = firstToken.mid(m_singleLineCommentIntro.length());
+            m_comment += firstToken.mid(m_singleLineCommentIntro.length());
             continue;
         }
         if (! parseStmt())
