@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 #include "umluniqueconstraintdialog.h"
 
@@ -34,6 +34,8 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
+DEBUG_REGISTER(UMLUniqueConstraintDialog)
+
 /**
  *  Sets up the UMLUniqueConstraintDialog.
  *  @param parent   The parent to the UMLUniqueConstraintDialog.
@@ -122,8 +124,8 @@ void UMLUniqueConstraintDialog::setupDialog()
     comboButtonHBoxLayout->addWidget(buttonBox);
 
     // We first insert all attributes to the combo box
-    UMLEntity* ue = m_pUniqueConstraint->umlParent()->asUMLEntity();
-    uDebug() << ue;
+    const UMLEntity* ue = m_pUniqueConstraint->umlParent()->asUMLEntity();
+    logDebug1("UMLUniqueConstraintDialog::setupDialog: UniqueConstraint parent=%1", ue->name());
     if (ue) {
        UMLClassifierListItemList ual = ue->getFilteredList(UMLObject::ot_EntityAttribute);
        foreach(UMLClassifierListItem* att, ual) {
