@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2018-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "widgetbasepopupmenu.h"
@@ -517,7 +517,8 @@ void WidgetBasePopupMenu::insertSingleSelectionMenu(WidgetBase* widget)
         }
         break;
     default:
-        uWarning() << "unhandled WidgetType " << WidgetBase::toString(type);
+        logWarn1("WidgetBasePopupMenu::insertSingleSelectionMenu unhandled WidgetType %1",
+                 WidgetBase::toString(type));
         break;
     }//end switch
 }
