@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef UML_H
@@ -114,6 +114,12 @@ public:
     WorkToolBar* workToolBar() const;
     DocWindow * docWindow() const;
     QListWidget *logWindow() const;
+    bool logToConsole() const;
+    void log(const QString& s);
+    void logDebug(const QString& s);
+    void logInfo(const QString& s);
+    void logWarn(const QString& s);
+    void logError(const QString& s);
 
     QCursor defaultCursor() const;
 
@@ -189,7 +195,7 @@ public:
 
     QString activeLanguageScopeSeparator() const;
 
-    KConfig* config() const;
+    KConfig* config();
     void importFiles(QStringList& fileList, const QString &rootPath = QString());
 
     static bool shuttingDown();
@@ -524,4 +530,47 @@ signals:
     friend class UMLView;
 };
 
+#define logDebug0(s) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                     UMLApp::app()->logDebug(QLatin1String(s))
+#define logInfo0(s)  UMLApp::app()->logInfo(QLatin1String(s))
+#define logWarn0(s)  UMLApp::app()->logWarn(QLatin1String(s))
+#define logError0(s) UMLApp::app()->logError(QLatin1String(s))
+
+#define logDebug1(s, a) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                        do { QString fmt = QString(QLatin1String(s)).arg(a); UMLApp::app()->logDebug(fmt); } while (0)
+#define logInfo1(s, a)  do { QString fmt = QString(QLatin1String(s)).arg(a); UMLApp::app()->logInfo(fmt);  } while (0)
+#define logWarn1(s, a)  do { QString fmt = QString(QLatin1String(s)).arg(a); UMLApp::app()->logWarn(fmt);  } while (0)
+#define logError1(s, a) do { QString fmt = QString(QLatin1String(s)).arg(a); UMLApp::app()->logError(fmt); } while (0)
+
+#define logDebug2(s, a, b) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                           do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b); UMLApp::app()->logDebug(fmt); } while (0)
+#define logInfo2(s, a, b)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b); UMLApp::app()->logInfo(fmt);  } while (0)
+#define logWarn2(s, a, b)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b); UMLApp::app()->logWarn(fmt);  } while (0)
+#define logError2(s, a, b) do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b); UMLApp::app()->logError(fmt); } while (0)
+
+#define logDebug3(s, a, b, c) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                              do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c); UMLApp::app()->logDebug(fmt); } while (0)
+#define logInfo3(s, a, b, c)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c); UMLApp::app()->logInfo(fmt);  } while (0)
+#define logWarn3(s, a, b, c)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c); UMLApp::app()->logWarn(fmt);  } while (0)
+#define logError3(s, a, b, c) do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c); UMLApp::app()->logError(fmt); } while (0)
+
+#define logDebug4(s, a, b, c, d) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                                 do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d); UMLApp::app()->logDebug(fmt); } while (0)
+#define logInfo4(s, a, b, c, d)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d); UMLApp::app()->logInfo(fmt);  } while (0)
+#define logWarn4(s, a, b, c, d)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d); UMLApp::app()->logWarn(fmt);  } while (0)
+#define logError4(s, a, b, c, d) do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d); UMLApp::app()->logError(fmt); } while (0)
+
+#define logDebug5(s, a, b, c, d, e) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+                                    do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d).arg(e); \
+                                    UMLApp::app()->logDebug(fmt); } while (0)
+#define logInfo5(s, a, b, c, d, e)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d).arg(e); \
+                                    UMLApp::app()->logInfo(fmt);  } while (0)
+#define logWarn5(s, a, b, c, d, e)  do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d).arg(e); \
+                                    UMLApp::app()->logWarn(fmt);  } while (0)
+#define logError5(s, a, b, c, d, e) do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d).arg(e); \
+                                    UMLApp::app()->logError(fmt); } while (0)
+
+#define logDebug6(s, a, b, c, d, e, f) if (UMLApp::app()->logToConsole() || Tracer::instance()->isEnabled(DBG_SRC)) \
+        do { QString fmt = QString(QLatin1String(s)).arg(a).arg(b).arg(c).arg(d).arg(e).arg(f); UMLApp::app()->logDebug(fmt); } while (0)
+
 #endif // UML_H
